@@ -7,6 +7,13 @@ from fpdf import FPDF
 
 
 def main():
+
+  
+  pdf = FPDF(orientation='L', format='A4')
+  pdf.add_font(family='montserrat', fname='X:\9999_BID_AMS\AMS-VFB_Fonts\Montserrat-ExtraBold.ttf', uni=True)
+  
+
+  
   cwd = os.getcwd()
   if cwd[0] != 'X':
     click.secho("Please run the tool in the X:/ drive")
@@ -23,7 +30,7 @@ def main():
 
   print(proj_number)
 
-  project_name = input("Type in the project name")
+  project_name = input("Type in the project name: ")
 
   stills = os.path.join(cwd, 'Test_Stills')
 
@@ -37,22 +44,28 @@ def main():
     click.secho(f"You need a folder called 'POV' inside {stills}")
     return
 
-  pdf = FPDF(orientation='L', format='A4')
-  pdf.set_font('Arial', 'B', 16)
-
 
   pdf.add_page()
-  pdf.cell(40,10, 'Animotions')
-  pdf.cell(40,20, 'beyond the visual')
+  pdf.cell(80)
+  pdf.set_font('montserrat', 32)
+  pdf.cell(w=40, txt='Animotions',ln=1,frame=1)
+  pdf.set_font('montserrat', 16)
+  pdf.cell(w=40, txt='beyond the visual',ln=1,frame=1)
+  pdf.set_font('Arial', 14)
+  pdf.cell(w=40, txt='www.animotions.be',ln=1)
+
+  pdf.add_page()
+  pdf.cell(80)
+  pdf.cell(80,txt=project_name)
+  pdf.set_font('Arial', 'B', 16)
 
   files = [x for x in os.listdir(pov) if "CAM" in x]
   for f in files:
     pdf.add_page()
     camname = os.path.splitext(f)[0]
-    pdf.cell(40,0, project_name)
-    pdf.cell(40,10,camname)
-    pdf.cell(40,20, proj_number)
-
+    pdf.cell(w=40,h=0, txt=project_name, align='L', ln=1)
+    pdf.cell(w=40,h=10,txt=camname, align='L')
+    
   mv = os.path.join(cwd, 'MV')
 
   mvs = [int(x[0:1]) for x in os.listdir(mv)]
